@@ -8,7 +8,6 @@ L.Storage = new L.StorageSingleton();
 L.S = L.Storage;
 L.Storage.Map = L.Map.extend({});
 
-
 /*
 * Utils
 */
@@ -186,6 +185,21 @@ L.DomUtil.after = function (target, el)
     return el;
 };
 
+L.DomUtil.RGBRegex = /rgb *\( *([0-9]{1,3}) *, *([0-9]{1,3}) *, *([0-9]{1,3}) *\)/;
+
+L.DomUtil.TextColorFromBackgroundColor = function (el) {
+    var out = '#000000';
+    if (!window.getComputedStyle) {return out;}
+    var rgb = window.getComputedStyle(el).getPropertyValue('background-color');
+    rgb = L.DomUtil.RGBRegex.exec(rgb);
+    if (!rgb || rgb.length != 4) {return out;}
+    rgb = parseInt(rgb[1], 10) + parseInt(rgb[2], 10) + parseInt(rgb[3], 10);
+    if (rgb < (255 * 3 / 2)) {
+        out = '#ffffff';
+    }
+    return out;
+};
+
 
 /*
 * Global events
@@ -196,12 +210,20 @@ L.S.Keys = {
     RIGHT: 39,
     DOWN: 40,
     TAB: 9,
-    RETURN: 13,
+    ENTER: 13,
     ESC: 27,
     APPLE: 91,
     SHIFT: 16,
     ALT: 17,
-    CTRL: 18
+    CTRL: 18,
+    E: 69,
+    H: 72,
+    I: 73,
+    L: 76,
+    M: 77,
+    P: 80,
+    S: 83,
+    Z: 90
 };
 L.S._onKeyDown = function (e) {
     if (e.keyCode == L.S.Keys.ESC) {
