@@ -179,6 +179,7 @@ L.Storage.Map.include({
         }
 
         this.help = new L.Storage.Help(this);
+        this.slideshow = new L.S.Slideshow(this, this.options.slideshow);
         this.initCaptionBar();
         if (this.options.allowEdit) {
             // Layer for items added by users
@@ -255,7 +256,6 @@ L.Storage.Map.include({
         };
         this.backupOptions();
         this.initContextMenu();
-        this.slideshow = new L.S.Slideshow(this, this.options.slideshow);
     },
 
     overrideBooleanOptionFromQueryString: function (name) {
@@ -270,6 +270,7 @@ L.Storage.Map.include({
         }
 
         L.DomUtil.classIf(document.body, 'storage-caption-bar-enabled', this.options.captionBar || (this.options.slideshow && this.options.slideshow.delay));
+        L.DomUtil.classIf(document.body, 'storage-slideshow-enabled', this.options.slideshow && this.options.slideshow.delay);
         if (this.options.zoomControl) {
             this._controls.zoomControl = (new L.Control.Zoom({zoomInTitle: L._('Zoom in'), zoomOutTitle: L._('Zoom out')})).addTo(this);
         }
@@ -1005,7 +1006,7 @@ L.Storage.Map.include({
         var slideshow = L.DomUtil.createFieldset(container, L._('Slideshow'));
         var slideshowFields = [
             ['options.slideshow.delay', {handler: 'IntInput', placeholder: L._('Set a value for adding a slideshow'), helpText: L._('Delay between elements (in milliseconds)')}],
-            ['options.slideshow.autorun', {handler: 'CheckBox', helpText: L._('Autostart slideshow when map is loaded?')}]
+            ['options.slideshow.autoplay', {handler: 'CheckBox', helpText: L._('Autostart slideshow when map is loaded?')}]
         ];
         var slideshowHandler = function () {
             this.slideshow.setOptions(this.options.slideshow);
@@ -1084,11 +1085,9 @@ L.Storage.Map.include({
         };
         L.bind(setName, this)();
         this.on('synced', L.bind(setName, this));
-        if (this.options.slideshow && this.options.slideshow.delay) {
-            this.onceDatalayersLoaded(function () {
-                container.appendChild(this.slideshow.renderToolbox());
-            });
-        }
+        this.onceDatalayersLoaded(function () {
+            container.appendChild(this.slideshow.renderToolbox());
+        });
     },
 
     initEditBar: function () {
