@@ -321,7 +321,7 @@ L.Storage.DataLayer = L.Class.extend({
     },
 
     resetOptions: function (options) {
-        this.options = L.Util.extend({}, options);
+        this.options = L.Util.CopyJSON(options || {});
         this.resetLayer();
     },
 
@@ -449,7 +449,7 @@ L.Storage.DataLayer = L.Class.extend({
         var geometry = geojson.type === 'Feature' ? geojson.geometry : geojson;
         if (!geometry) return;  // null geometry is valid geojson.
         var coords = geometry.coordinates,
-            layer;
+            layer, tmp;
 
         switch (geometry.type) {
             case 'Point':
@@ -464,6 +464,17 @@ L.Storage.DataLayer = L.Class.extend({
                 latlngs = L.GeoJSON.coordsToLatLngs(coords, 1);
                 layer = this._polygonToLayer(geojson, latlngs);
                 break;
+            case 'MultiLineString':
+                // Merge instead of failing for now
+                if (coords.length >= 1) {
+                    tmp = [];
+                    for (var j=0, l=coords.length; j<l; j++) {
+                        tmp = tmp.concat(coords[j]);
+                    }
+                    latlngs = L.GeoJSON.coordsToLatLngs(tmp);
+                    layer = this._lineToLayer(geojson, latlngs);
+                    break;
+                }
             case 'MultiPolygon':
                 // Hack: we handle only MultiPolygon with one polygon
                 if (coords.length === 1) {
@@ -623,8 +634,7 @@ L.Storage.DataLayer = L.Class.extend({
 
     edit: function () {
         if(!this.map.editEnabled || !this.isLoaded()) {return;}
-        var self = this,
-            container = L.DomUtil.create('div'),
+        var container = L.DomUtil.create('div'),
             metadata_fields = [
                 'options.name',
                 'options.description',
